<?php

namespace Litepie\Plan\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepie\Plan\Models\PlanFeature;

class PlanFeaturePolicy
{

    /**
     * Determine if the given user can view the plan_feature.
     *
     * @param UserPolicyInterface $authUser
     * @param PlanFeature $plan_feature
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, PlanFeature $plan_feature)
    {
        if ($authUser->canDo('plan.plan_feature.view') && $authUser->isAdmin()) {
            return true;
        }

        return $plan_feature->user_id == user_id() && $plan_feature->user_type == user_type();
    }

    /**
     * Determine if the given user can create a plan_feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('plan.plan_feature.create');
    }

    /**
     * Determine if the given user can update the given plan_feature.
     *
     * @param UserPolicyInterface $authUser
     * @param PlanFeature $plan_feature
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, PlanFeature $plan_feature)
    {
        if ($authUser->canDo('plan.plan_feature.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $plan_feature->user_id == user_id() && $plan_feature->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given plan_feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, PlanFeature $plan_feature)
    {
        return $plan_feature->user_id == user_id() && $plan_feature->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given plan_feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, PlanFeature $plan_feature)
    {
        if ($authUser->canDo('plan.plan_feature.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given plan_feature.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, PlanFeature $plan_feature)
    {
        if ($authUser->canDo('plan.plan_feature.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
