<?php

namespace Litepie\Plan\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepie\Plan\Models\Plan;

class PlanPolicy
{

    /**
     * Determine if the given user can view the plan.
     *
     * @param UserPolicyInterface $authUser
     * @param Plan $plan
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Plan $plan)
    {
        if ($authUser->canDo('plan.plan.view') && $authUser->isAdmin()) {
            return true;
        }

        return $plan->user_id == user_id() && $plan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('plan.plan.create');
    }

    /**
     * Determine if the given user can update the given plan.
     *
     * @param UserPolicyInterface $authUser
     * @param Plan $plan
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Plan $plan)
    {
        if ($authUser->canDo('plan.plan.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $plan->user_id == user_id() && $plan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Plan $plan)
    {
        return $plan->user_id == user_id() && $plan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Plan $plan)
    {
        if ($authUser->canDo('plan.plan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Plan $plan)
    {
        if ($authUser->canDo('plan.plan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
