<?php

namespace Litepie\Plan\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepie\Plan\Models\PlanSubscriptionUsage;

class PlanSubscriptionUsagePolicy
{

    /**
     * Determine if the given user can view the plan_subscription_usage.
     *
     * @param UserPolicyInterface $authUser
     * @param PlanSubscriptionUsage $plan_subscription_usage
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, PlanSubscriptionUsage $plan_subscription_usage)
    {
        if ($authUser->canDo('plan.plan_subscription_usage.view') && $authUser->isAdmin()) {
            return true;
        }

        return $plan_subscription_usage->user_id == user_id() && $plan_subscription_usage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a plan_subscription_usage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('plan.plan_subscription_usage.create');
    }

    /**
     * Determine if the given user can update the given plan_subscription_usage.
     *
     * @param UserPolicyInterface $authUser
     * @param PlanSubscriptionUsage $plan_subscription_usage
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, PlanSubscriptionUsage $plan_subscription_usage)
    {
        if ($authUser->canDo('plan.plan_subscription_usage.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $plan_subscription_usage->user_id == user_id() && $plan_subscription_usage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given plan_subscription_usage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, PlanSubscriptionUsage $plan_subscription_usage)
    {
        return $plan_subscription_usage->user_id == user_id() && $plan_subscription_usage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given plan_subscription_usage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, PlanSubscriptionUsage $plan_subscription_usage)
    {
        if ($authUser->canDo('plan.plan_subscription_usage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given plan_subscription_usage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, PlanSubscriptionUsage $plan_subscription_usage)
    {
        if ($authUser->canDo('plan.plan_subscription_usage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
