<?php

namespace Litepie\Plan\Providers;

use Illuminate\Support\ServiceProvider;
use Litepie\Plan\Plan;

class PlanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'plan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'plan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litepie\Plan\Providers\AuthServiceProvider::class);
        $this->app->register(\Litepie\Plan\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litepie\Plan\Providers\EventServiceProvider::class);
        // $this->app->register(\Litepie\Plan\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litepie.plan', function($app)
        {
            return $this->app->make(Plan::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Plan to repository
        $this->app->bind(
            'Litepie\Plan\Interfaces\PlanRepositoryInterface',
            \Litepie\Plan\Repositories\Eloquent\PlanRepository::class
        );        // Bind PlanFeature to repository
        $this->app->bind(
            'Litepie\Plan\Interfaces\PlanFeatureRepositoryInterface',
            \Litepie\Plan\Repositories\Eloquent\PlanFeatureRepository::class
        );        // Bind PlanSubscriptionUsage to repository
        $this->app->bind(
            'Litepie\Plan\Interfaces\PlanSubscriptionUsageRepositoryInterface',
            \Litepie\Plan\Repositories\Eloquent\PlanSubscriptionUsageRepository::class
        );        // Bind PlanSubscription to repository
        $this->app->bind(
            'Litepie\Plan\Interfaces\PlanSubscriptionRepositoryInterface',
            \Litepie\Plan\Repositories\Eloquent\PlanSubscriptionRepository::class
        );
    }


    /**
     * Merges user's and plan's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.plan'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litepie\Plan\Commands\Plan::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.plan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepie/plan.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/plan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/plan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
