<?php

namespace Litepie\Plan\Workflow;

use Litepie\Plan\Models\Plan;
use Validator;

class PlanValidator
{

    /**
     * Determine if the given plan is valid for complete status.
     *
     * @param Plan $plan
     *
     * @return bool / Validator
     */
    public function complete(Plan $plan)
    {
        return Validator::make($plan->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given plan is valid for verify status.
     *
     * @param Plan $plan
     *
     * @return bool / Validator
     */
    public function verify(Plan $plan)
    {
        return Validator::make($plan->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given plan is valid for approve status.
     *
     * @param Plan $plan
     *
     * @return bool / Validator
     */
    public function approve(Plan $plan)
    {
        return Validator::make($plan->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given plan is valid for publish status.
     *
     * @param Plan $plan
     *
     * @return bool / Validator
     */
    public function publish(Plan $plan)
    {
        return Validator::make($plan->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given plan is valid for archive status.
     *
     * @param Plan $plan
     *
     * @return bool / Validator
     */
    public function archive(Plan $plan)
    {
        return Validator::make($plan->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given plan is valid for unpublish status.
     *
     * @param Plan $plan
     *
     * @return bool / Validator
     */
    public function unpublish(Plan $plan)
    {
        return Validator::make($plan->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
